Change in osmo-bsc[master]: Fix typo in function nanobts_attr_nsvc_get

This is merely a historical archive of years 2008-2021, before the migration to mailman3.

A maintained and still updated list archive can be found at https://lists.osmocom.org/hyperkitty/list/gerrit-log@lists.osmocom.org/.

laforge gerrit-no-reply at lists.osmocom.org
Fri Dec 4 18:33:32 UTC 2020


laforge has submitted this change. ( https://gerrit.osmocom.org/c/osmo-bsc/+/21538 )

Change subject: Fix typo in function nanobts_attr_nsvc_get
......................................................................

Fix typo in function nanobts_attr_nsvc_get

Change-Id: I50235ba7b045ab7fba2112e61191d2756a67dfdc
---
M include/osmocom/bsc/bts_ipaccess_nanobts_omlattr.h
M src/osmo-bsc/bts_ipaccess_nanobts_omlattr.c
M src/osmo-bsc/nm_gprs_nsvc_fsm.c
M tests/nanobts_omlattr/nanobts_omlattr_test.c
M tests/nanobts_omlattr/nanobts_omlattr_test.ok
5 files changed, 13 insertions(+), 13 deletions(-)

Approvals:
  Jenkins Builder: Verified
  laforge: Looks good to me, approved



diff --git a/include/osmocom/bsc/bts_ipaccess_nanobts_omlattr.h b/include/osmocom/bsc/bts_ipaccess_nanobts_omlattr.h
index 22a8c34..687f16a 100644
--- a/include/osmocom/bsc/bts_ipaccess_nanobts_omlattr.h
+++ b/include/osmocom/bsc/bts_ipaccess_nanobts_omlattr.h
@@ -31,6 +31,6 @@
 struct msgb *nanobts_attr_bts_get(struct gsm_bts *bts);
 struct msgb *nanobts_attr_nse_get(struct gsm_bts_sm *bts_sm);
 struct msgb *nanobts_attr_cell_get(struct gsm_bts *bts);
-struct msgb *nanobts_attr_nscv_get(struct gsm_bts *bts);
+struct msgb *nanobts_attr_nsvc_get(struct gsm_bts *bts);
 struct msgb *nanobts_attr_radio_get(struct gsm_bts *bts,
 				    struct gsm_bts_trx *trx);
diff --git a/src/osmo-bsc/bts_ipaccess_nanobts_omlattr.c b/src/osmo-bsc/bts_ipaccess_nanobts_omlattr.c
index e23a688..885f4cc 100644
--- a/src/osmo-bsc/bts_ipaccess_nanobts_omlattr.c
+++ b/src/osmo-bsc/bts_ipaccess_nanobts_omlattr.c
@@ -199,7 +199,7 @@
 	return msgb;
 }
 
-struct msgb *nanobts_attr_nscv_get(struct gsm_bts *bts)
+struct msgb *nanobts_attr_nsvc_get(struct gsm_bts *bts)
 {
 	struct msgb *msgb;
 	uint8_t buf[256];
diff --git a/src/osmo-bsc/nm_gprs_nsvc_fsm.c b/src/osmo-bsc/nm_gprs_nsvc_fsm.c
index d28dfd3..ffc5659 100644
--- a/src/osmo-bsc/nm_gprs_nsvc_fsm.c
+++ b/src/osmo-bsc/nm_gprs_nsvc_fsm.c
@@ -103,7 +103,7 @@
 			return;
 		}
 		nsvc->mo.set_attr_sent = true;
-		msgb = nanobts_attr_nscv_get(nsvc->bts);
+		msgb = nanobts_attr_nsvc_get(nsvc->bts);
 		OSMO_ASSERT(msgb);
 		abis_nm_ipaccess_set_attr(nsvc->bts, NM_OC_GPRS_NSVC, nsvc->bts->bts_nr,
 					  nsvc->id, 0xff, msgb->data, msgb->len);
diff --git a/tests/nanobts_omlattr/nanobts_omlattr_test.ok b/tests/nanobts_omlattr/nanobts_omlattr_test.ok
index abdb95e..2f3ff77 100644
--- a/tests/nanobts_omlattr/nanobts_omlattr_test.ok
+++ b/tests/nanobts_omlattr/nanobts_omlattr_test.ok
@@ -13,17 +13,17 @@
 expected=9a0001009c000205039e00020002a30009140505a0050a04080fa800020f00a9000500fa00fa02
 ok.
 
-Testing nanobts_attr_nscv_get()...
+Testing nanobts_attr_nsvc_get()...
 result=  9f00020065a2000859d80a0901655a3c
 expected=9f00020065a2000859d80a0901655a3c
 ok.
 
-Testing nanobts_attr_nscv_get()...
+Testing nanobts_attr_nsvc_get()...
 result=  2d0b0500020362
 expected=2d0b0500020362
 ok.
 
-Testing nanobts_attr_nscv_get()...
+Testing nanobts_attr_nsvc_get()...
 result=  9f00020065fd001629005a3c59e2fd005678901234567890123456789012
 expected=9f00020065fd001629005a3c59e2fd005678901234567890123456789012
 ok.

diff --git a/tests/nanobts_omlattr/nanobts_omlattr_test.c b/tests/nanobts_omlattr/nanobts_omlattr_test.c
index 6e85138..73ba869 100644
--- a/tests/nanobts_omlattr/nanobts_omlattr_test.c
+++ b/tests/nanobts_omlattr/nanobts_omlattr_test.c
@@ -151,13 +151,13 @@
 	printf("\n");
 }
 
-static void test_nanobts_attr_nscv_get(struct gsm_bts *bts, uint8_t *expected)
+static void test_nanobts_attr_nsvc_get(struct gsm_bts *bts, uint8_t *expected)
 {
 	struct msgb *msgb;
 
-	printf("Testing nanobts_attr_nscv_get()...\n");
+	printf("Testing nanobts_attr_nsvc_get()...\n");
 
-	msgb = nanobts_attr_nscv_get(bts);
+	msgb = nanobts_attr_nsvc_get(bts);
 	printf("result=  %s\n", osmo_hexdump_nospc(msgb->data, msgb->len));
 	printf("expected=%s\n", osmo_hexdump_nospc(expected, msgb->len));
 	OSMO_ASSERT(memcmp(msgb->data, expected, msgb->len) == 0);
@@ -173,7 +173,7 @@
 {
 	struct msgb *msgb;
 
-	printf("Testing nanobts_attr_nscv_get()...\n");
+	printf("Testing nanobts_attr_nsvc_get()...\n");
 
 	msgb = nanobts_attr_radio_get(bts, trx);
 	printf("result=  %s\n", osmo_hexdump_nospc(msgb->data, msgb->len));
@@ -263,7 +263,7 @@
 		0xfa, 0x00, 0xfa, 0x02
 	};
 
 	/* Parameters needed to test nanobts_attr_nscv_get() */
 	struct osmo_sockaddr_str addr;
 	osmo_sockaddr_str_from_str(&addr, "10.9.1.101", 23000);
 	osmo_sockaddr_str_to_sockaddr(&addr, &bts->site_mgr->gprs.nsvc[0].remote.u.sas);
@@ -285,7 +285,7 @@
 	test_nanobts_attr_bts_get(bts, attr_bts_expected);
 	test_nanobts_attr_nse_get(bts, attr_nse_expected);
 	test_nanobts_attr_cell_get(bts, attr_cell_expected);
-	test_nanobts_attr_nscv_get(bts, attr_nscv_expected);
+	test_nanobts_attr_nsvc_get(bts, attr_nscv_expected);
 	test_nanobts_attr_radio_get(bts, trx, attr_radio_expected);
 
 	/* NSVC IPv6 test */
@@ -303,7 +303,7 @@
 	      0xfd, 0x00, 0x56, 0x78, 0x90, 0x12, 0x34, 0x56,
 	      0x78, 0x90, 0x12, 0x34, 0x56, 0x78, 0x90, 0x12,
 	    };
-	test_nanobts_attr_nscv_get(bts, attr_nscv6_expected);
+	test_nanobts_attr_nsvc_get(bts, attr_nscv6_expected);
 
 
 	printf("Done\n");
@@ -263,7 +263,7 @@
 	};
 
-	/* Parameters needed to test nanobts_attr_nscv_get() */
+	/* Parameters needed to test nanobts_attr_nsvc_get() */
 	struct osmo_sockaddr_str addr;
 	osmo_sockaddr_str_from_str(&addr, "10.9.1.101", 23000);
-- 
To view, visit https://gerrit.osmocom.org/c/osmo-bsc/+/21538
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bsc
Gerrit-Branch: master
Gerrit-Change-Id: I50235ba7b045ab7fba2112e61191d2756a67dfdc
Gerrit-Change-Number: 21538
Gerrit-PatchSet: 1
Gerrit-Owner: pespin <pespin at sysmocom.de>
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: laforge <laforge at osmocom.org>
Gerrit-MessageType: merged
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.osmocom.org/pipermail/gerrit-log/attachments/20201204/b7b5f2c1/attachment.htm>


More information about the gerrit-log mailing list